@@ -6,6 +6,8 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
+#![recursion_limit = "256"]
+
 use bls::PublicKey;
 use eyre::{eyre, Context, Error, Result};
 use futures::{
@@ -23,7 +25,7 @@ use std::{
     collections::BTreeMap,
     fs::File,
     io::BufWriter,
-    net::{Ipv4Addr, SocketAddr},
+    net::SocketAddr,
     time::{Duration, Instant},
 };
 use structopt::StructOpt;
@@ -39,11 +41,9 @@ use yansi::{Color, Style};
 use safe_network::routing::create_test_used_space_and_root_storage;
 
 use safe_network::messaging::{
-    data::Error::FailedToWriteFile, node::NodeMsg, DstLocation, MessageId,
-};
-use safe_network::routing::{
-    Cache, Config, Event as RoutingEvent, NodeElderChange, Routing, TransportConfig,
+    data::Error::FailedToWriteFile, system::SystemMsg, DstLocation, MessageId,
 };
+use safe_network::routing::{Cache, Config, Event as RoutingEvent, NodeElderChange, Routing};
 
 // Minimal delay between two consecutive prints of the network status.
 const MIN_PRINT_DELAY: Duration = Duration::from_millis(500);
@@ -213,19 +213,15 @@ impl Network {
 
     // Create new node and let it join the network.
     async fn create_node(&mut self, event_tx: Sender<Event>) {
-        let bootstrap_addrs = self.get_bootstrap_addrs().await;
+        let bootstrap_nodes = self.get_bootstrap_addrs().await;
 
         let id = self.new_node_id();
         let _ = self.nodes.insert(id, Node::Joining);
         self.stats.join_attempts += 1;
 
         let config = Config {
-            first: bootstrap_addrs.is_empty(),
-            transport_config: TransportConfig {
-                hard_coded_contacts: bootstrap_addrs.into_iter().collect(),
-                local_ip: Some(Ipv4Addr::LOCALHOST.into()),
-                ..Default::default()
-            },
+            first: bootstrap_nodes.is_empty(),
+            bootstrap_nodes,
             ..Default::default()
         };
 
@@ -360,7 +356,7 @@ impl Network {
                     let (dst, dest_section_pk) = match dst {
                         DstLocation::Section { name, section_pk } => (name, section_pk),
                         DstLocation::Node { name, section_pk } => (name, section_pk),
-                        DstLocation::DirectAndUnrouted(_) | DstLocation::EndUser(_) => {
+                        DstLocation::EndUser(_) => {
                             return Err(eyre!("unexpected probe message dst: {:?}", dst))
                         }
                     };
@@ -462,7 +458,7 @@ impl Network {
         // section health to appear lower than it actually is.
 
         // just some valid message
-        let node_msg = NodeMsg::NodeMsgError {
+        let node_msg = SystemMsg::NodeMsgError {
             error: FailedToWriteFile,
             correlation_id: MessageId::new(),
         };
