@@ -124,9 +124,11 @@ impl Client {
             .send_query(DataQuery::Chunk(ChunkRead::Get(head_address)))
             .await?;
 
-        let msg_id = res.msg_id;
+        let operation_id = res.operation_id;
         let chunk: Chunk = match res.response {
-            QueryResponse::GetChunk(result) => result.map_err(|err| Error::from((err, msg_id))),
+            QueryResponse::GetChunk(result) => {
+                result.map_err(|err| Error::from((err, operation_id)))
+            }
             _ => return Err(Error::ReceivedUnexpectedEvent),
         }?;
 
@@ -361,7 +363,7 @@ mod tests {
     use self_encryption::{SelfEncryptionError, Storage};
     use tokio::time::{Duration, Instant};
 
-    const BLOB_TEST_QUERY_TIMEOUT: u64 = 90;
+    const BLOB_TEST_QUERY_TIMEOUT: u64 = 60;
 
     // Test storing and getting public Blob.
     #[tokio::test(flavor = "multi_thread")]
@@ -474,13 +476,14 @@ mod tests {
         client.delete_blob(priv_address).await?;
 
         // Make sure Blob was deleted
-        let mut attempts = 10u8;
+        let mut attempts = 20u8;
         let orignal_timeout = client.query_timeout;
         client.query_timeout = Duration::from_secs(5); // override with a short timeout
                                                        // clear cache first
         client.clear_blob_cache().await;
 
         while client.read_blob(priv_address, None, None).await.is_ok() {
+            client.clear_blob_cache().await;
             tokio::time::sleep(tokio::time::Duration::from_millis(4000)).await;
             if attempts == 0 {
                 bail!("The private chunk was not deleted: {:?}", priv_address);
@@ -525,6 +528,7 @@ mod tests {
         };
 
         client.delete_blob(address).await?;
+
         client.clear_blob_cache().await;
 
         client.query_timeout = Duration::from_secs(5); // override with a short timeout
@@ -574,16 +578,18 @@ mod tests {
         let size = 1024;
         let data = generate_random_vector(size);
 
-        let client = create_test_client(Some(BLOB_TEST_QUERY_TIMEOUT)).await?;
+        let mut client = create_test_client(Some(BLOB_TEST_QUERY_TIMEOUT)).await?;
         let address = client.store_public_blob(&data).await?;
 
         // let's make sure the public chunk is stored
         let _ = run_w_backoff_delayed(|| client.read_blob(address, None, None), 10).await?;
 
+        client.query_timeout = Duration::from_secs(5);
         // and now trying to read a private chunk with same address should fail
         let res = client
             .read_blob(ChunkAddress::Private(*address.name()), None, None)
             .await;
+
         assert!(res.is_err());
 
         Ok(())
@@ -595,13 +601,15 @@ mod tests {
 
         let value = generate_random_vector(size);
 
-        let client = create_test_client(Some(BLOB_TEST_QUERY_TIMEOUT)).await?;
+        let mut client = create_test_client(Some(BLOB_TEST_QUERY_TIMEOUT)).await?;
 
         let address = client.store_private_blob(&value).await?;
 
         // let's make sure the private chunk is stored
         let _ = run_w_backoff_delayed(|| client.read_blob(address, None, None), 10).await?;
 
+        client.query_timeout = Duration::from_secs(5);
+
         // and now trying to read a public chunk with same address should fail (timeout)
         let res = client
             .read_blob(ChunkAddress::Public(*address.name()), None, None)
