@@ -8,13 +8,11 @@
 
 pub use crate::messaging::data::Error as ErrorMessage;
 use crate::messaging::{
-    data::{CmdError, QueryResponse},
-    Error as MessagingError, MessageId,
+    data::{CmdError, OperationId, QueryResponse},
+    Error as MessagingError,
 };
 use crate::types::Error as DtError;
-use qp2p::Error as QuicP2pError;
 use std::io;
-
 use thiserror::Error;
 
 /// Specialisation of `std::Result` for Client.
@@ -25,6 +23,9 @@ pub type Result<T, E = Error> = std::result::Result<T, E>;
 #[derive(Error, Debug)]
 #[non_exhaustive]
 pub enum Error {
+    /// Signature Aggregation Error
+    #[error("Error on aggregating signatures from network")]
+    Aggregation(String),
     /// Asymmetric Key Decryption Failed.
     #[error("Asymmetric key decryption failure")]
     AsymmetricDecipherFailure,
@@ -84,6 +85,9 @@ pub enum Error {
     /// Incorrect user permissions were returned
     #[error("Incorrect user permissions were returned")]
     IncorrectPermissions,
+    /// No operation Id could be found
+    #[error("Could not retrieve the operation id of a query response")]
+    UnknownOperationId,
     /// Unexpected response received
     #[error("Unexpected response received when querying {0:?}")]
     UnexpectedQueryResponse(QueryResponse),
@@ -95,15 +99,15 @@ pub enum Error {
     NetworkDataError(#[from] DtError),
     /// Errors received from the network via sn_messaging
     #[error(
-        "Error received from the network: {:?} MessageId: {:?}",
+        "Error received from the network: {:?} Operationid: {:?}",
         source,
-        msg_id
+        op_id
     )]
     ErrorMessage {
         /// The source of an error message
         source: ErrorMessage,
-        /// Message ID that was used to send the query
-        msg_id: MessageId,
+        /// operation ID that was used to send the query
+        op_id: OperationId,
     },
     /// Errors occurred when serialising or deserialising messages
     #[error(transparent)]
@@ -117,9 +121,12 @@ pub enum Error {
     /// Io error.
     #[error(transparent)]
     IoError(#[from] io::Error),
+    /// Endpoint setup error.
+    #[error(transparent)]
+    EndpointSetup(#[from] qp2p::ClientEndpointError),
     /// QuicP2p error.
     #[error(transparent)]
-    QuicP2p(#[from] QuicP2pError),
+    QuicP2p(#[from] qp2p::SendError),
     /// Bincode error
     #[error(transparent)]
     Serialisation(#[from] Box<bincode::ErrorKind>),
@@ -131,15 +138,15 @@ pub enum Error {
     Database(#[from] crate::dbs::Error),
 }
 
-impl From<(CmdError, MessageId)> for Error {
-    fn from((error, msg_id): (CmdError, MessageId)) -> Self {
+impl From<(CmdError, OperationId)> for Error {
+    fn from((error, op_id): (CmdError, OperationId)) -> Self {
         let CmdError::Data(source) = error;
-        Error::ErrorMessage { source, msg_id }
+        Error::ErrorMessage { source, op_id }
     }
 }
 
-impl From<(ErrorMessage, MessageId)> for Error {
-    fn from((source, msg_id): (ErrorMessage, MessageId)) -> Self {
-        Self::ErrorMessage { source, msg_id }
+impl From<(ErrorMessage, OperationId)> for Error {
+    fn from((source, op_id): (ErrorMessage, OperationId)) -> Self {
+        Self::ErrorMessage { source, op_id }
     }
 }
