@@ -7,9 +7,9 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::messaging::{
-    node::{
-        JoinAsRelocatedRequest, JoinAsRelocatedResponse, NodeMsg, RelocateDetails, RelocatePayload,
-        Section,
+    system::{
+        JoinAsRelocatedRequest, JoinAsRelocatedResponse, RelocateDetails, RelocatePayload, Section,
+        SystemMsg,
     },
     AuthorityProof, DstLocation, SectionAuth, SectionAuthorityProvider, WireMsg,
 };
@@ -36,7 +36,7 @@ pub(crate) struct JoiningAsRelocated {
     genesis_key: BlsPublicKey,
     dst_section_key: BlsPublicKey,
     relocate_details: RelocateDetails,
-    node_msg: NodeMsg,
+    node_msg: SystemMsg,
     node_msg_auth: AuthorityProof<SectionAuth>,
     // Avoid sending more than one request to the same peer.
     used_recipients: HashSet<SocketAddr>,
@@ -48,7 +48,7 @@ impl JoiningAsRelocated {
         node: Node,
         genesis_key: BlsPublicKey,
         relocate_details: RelocateDetails,
-        node_msg: NodeMsg,
+        node_msg: SystemMsg,
         section_auth: AuthorityProof<SectionAuth>,
     ) -> Result<Self> {
         let dst_section_key = relocate_details.dst_key;
@@ -250,10 +250,13 @@ impl JoiningAsRelocated {
 
         info!("Sending {:?} to {:?}", join_request, recipients);
 
-        let node_msg = NodeMsg::JoinAsRelocatedRequest(Box::new(join_request));
+        let node_msg = SystemMsg::JoinAsRelocatedRequest(Box::new(join_request));
         let wire_msg = WireMsg::single_src(
             &self.node,
-            DstLocation::DirectAndUnrouted(self.dst_section_key),
+            DstLocation::Section {
+                name: XorName::from(PublicKey::Bls(self.dst_section_key)),
+                section_pk: self.dst_section_key,
+            },
             node_msg,
             self.genesis_key,
         )?;
