@@ -8,7 +8,7 @@
 
 use super::super::Core;
 use crate::messaging::{
-    node::{DkgFailureSig, DkgFailureSigSet, DkgKey, ElderCandidates, NodeMsg, Proposal},
+    system::{DkgFailureSig, DkgFailureSigSet, DkgKey, ElderCandidates, Proposal, SystemMsg},
     SectionAuthorityProvider,
 };
 use crate::routing::{
@@ -100,7 +100,7 @@ impl Core {
                 elder_candidates
             );
 
-            self.send_dkg_start_to(elder_candidates, slice::from_ref(sender))
+            self.send_dkg_start(elder_candidates, slice::from_ref(sender))
         } else {
             // The DKG failure is regarding failed_participants, i.e. potential unresponsive node.
             trace!(
@@ -134,7 +134,7 @@ impl Core {
     }
 
     pub(crate) fn handle_dkg_failure(&mut self, failure_set: DkgFailureSigSet) -> Result<Command> {
-        let node_msg = NodeMsg::DkgFailureAgreement(failure_set);
+        let node_msg = SystemMsg::DkgFailureAgreement(failure_set);
         self.send_message_to_our_elders(node_msg)
     }
 }
