@@ -7,11 +7,13 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::messaging::{
-    data::ServiceMsg,
-    node::{DkgFailureSigSet, KeyedSig, Proposal, Section},
-    AuthorityProof, EndUser, MessageId, SectionAuthorityProvider, ServiceAuth, WireMsg,
+    system::{DkgFailureSigSet, KeyedSig, Proposal, Section, SystemMsg},
+    DstLocation, MessageId, NodeMsgAuthority, SectionAuthorityProvider, WireMsg,
 };
 use crate::routing::{node::Node, routing_api::Peer, section::SectionKeyShare, XorName};
+use bls::PublicKey as BlsPublicKey;
+use bytes::Bytes;
+use custom_debug::Debug;
 use std::{
     net::SocketAddr,
     sync::atomic::{AtomicU64, Ordering},
@@ -23,17 +25,39 @@ use std::{
 #[derive(Debug)]
 pub(crate) enum Command {
     /// Handle `message` from `sender`.
-    /// holding the WireMsg that has been received from the network,
+    /// Holding the WireMsg that has been received from the network,
     HandleMessage {
         sender: SocketAddr,
         wire_msg: WireMsg,
     },
-    /// Handle ServiceMsg, either directly or notify via event listener
-    HandleServiceMessage {
+    // TODO: rename this as/when this is all node for clarity
+    /// Handle Node, either directly or notify via event listener
+    HandleSystemMessage {
+        sender: SocketAddr,
         msg_id: MessageId,
-        msg: ServiceMsg,
-        user: EndUser,
-        auth: AuthorityProof<ServiceAuth>,
+        msg: SystemMsg,
+        msg_authority: NodeMsgAuthority,
+        dst_location: DstLocation,
+        #[debug(skip)]
+        payload: Bytes,
+        #[debug(skip)]
+        known_keys: Vec<BlsPublicKey>,
+    },
+    /// Handle verified node message after aggregation either directly or notify via event listener
+    HandleVerifiedNodeNonDataMessage {
+        sender: SocketAddr,
+        msg_id: MessageId,
+        msg: SystemMsg,
+        msg_authority: NodeMsgAuthority,
+        #[debug(skip)]
+        known_keys: Vec<BlsPublicKey>,
+    },
+    /// Handle Node data messages directly
+    HandleVerifiedNodeDataMessage {
+        msg_id: MessageId,
+        msg: SystemMsg,
+        msg_authority: NodeMsgAuthority,
+        dst_location: DstLocation,
     },
     /// Handle a timeout previously scheduled with `ScheduleTimeout`.
     HandleTimeout(u64),
@@ -58,14 +82,14 @@ pub(crate) enum Command {
     },
     /// Parses WireMsg to send to the correct location
     ParseAndSendWireMsg(WireMsg),
+    /// Performs serialisation and signing for sending of NodeMst
+    PrepareNodeMsgToSend { msg: SystemMsg, dst: DstLocation },
     /// Send a message to `delivery_group_size` peers out of the given `recipients`.
     SendMessageDeliveryGroup {
         recipients: Vec<(XorName, SocketAddr)>,
         delivery_group_size: usize,
         wire_msg: WireMsg,
     },
-    /// Relay a message according to its destination.
-    RelayMessage(WireMsg),
     /// Schedule a timeout after the given duration. When the timeout expires, a `HandleTimeout`
     /// command is raised. The token is used to identify the timeout.
     ScheduleTimeout { duration: Duration, token: u64 },
