@@ -8,11 +8,12 @@
 
 use super::{Command, Event};
 use crate::messaging::{
-    node::{NodeMsg, Section},
+    data::{ChunkDataExchange, StorageLevel},
+    system::{Section, SystemMsg},
     DstLocation, EndUser, MsgKind, WireMsg,
 };
-use crate::node::RegisterStorage;
 use crate::routing::{
+    core::{ChunkStore, RegisterStorage},
     core::{Core, SendStatus},
     error::Result,
     messages::WireMsgUtils,
@@ -20,9 +21,12 @@ use crate::routing::{
     peer::PeerUtils,
     section::SectionPeersUtils,
     section::SectionUtils,
-    Error, XorName,
+    Error, Prefix, XorName,
 };
+// use bls::PublicKey;
+use crate::types::PublicKey;
 use itertools::Itertools;
+use std::collections::BTreeSet;
 use std::{net::SocketAddr, sync::Arc, time::Duration};
 use tokio::{
     sync::{watch, RwLock},
@@ -59,6 +63,27 @@ impl Dispatcher {
         self.core.read().await.register_storage.clone()
     }
 
+    pub(super) async fn get_chunk_storage(&self) -> ChunkStore {
+        self.core.read().await.chunk_storage.clone()
+    }
+
+    pub(super) async fn get_chunk_data_of(&self, prefix: &Prefix) -> ChunkDataExchange {
+        self.core.read().await.get_data_of(prefix).await
+    }
+
+    /// Returns whether the level changed or not.
+    pub(super) async fn set_storage_level(&self, node_id: &PublicKey, level: StorageLevel) -> bool {
+        self.core
+            .read()
+            .await
+            .set_storage_level(node_id, level)
+            .await
+    }
+
+    pub(super) async fn retain_members_only(&self, members: BTreeSet<XorName>) -> Result<()> {
+        self.core.read().await.retain_members_only(members).await
+    }
+
     /// Handles the given command and transitively any new commands that are produced during its
     /// handling.
     pub(super) async fn handle_commands(self: Arc<Self>, command: Command) -> Result<()> {
@@ -96,7 +121,7 @@ impl Dispatcher {
             trace!(?command);
 
             self.try_handle_command(command).await.map_err(|error| {
-                error!("Error encountered when handling command: {}", error);
+                error!("Error encountered when handling command: {:?}", error);
                 error
             })
         }
@@ -106,23 +131,76 @@ impl Dispatcher {
 
     async fn try_handle_command(&self, command: Command) -> Result<Vec<Command>> {
         match command {
-            Command::HandleMessage { sender, wire_msg } => {
-                self.core
-                    .write()
-                    .await
-                    .handle_message(sender, wire_msg)
-                    .await
-            }
-            Command::HandleServiceMessage {
+            // Data node msg that requires no locking
+            Command::HandleVerifiedNodeDataMessage {
                 msg_id,
-                user,
+                msg_authority,
+                dst_location,
                 msg,
-                auth,
             } => {
                 self.core
                     .read()
                     .await
-                    .handle_data_msg_received(msg_id, msg, user, auth)
+                    .handle_verified_data_message(
+                        // sender,
+                        msg_id,
+                        msg_authority,
+                        dst_location,
+                        msg,
+                    )
+                    .await
+            }
+            // Non-data node msg that requires locking
+            Command::HandleVerifiedNodeNonDataMessage {
+                sender,
+                msg_id,
+                msg_authority,
+                msg,
+                known_keys,
+            } => {
+                self.core
+                    .write()
+                    .await
+                    .handle_verified_non_data_node_message(
+                        sender,
+                        msg_id,
+                        msg_authority,
+                        msg,
+                        known_keys,
+                    )
+                    .await
+            }
+            Command::HandleSystemMessage {
+                sender,
+                msg_id,
+                msg_authority,
+                dst_location,
+                msg,
+                payload,
+                known_keys,
+            } => {
+                self.core
+                    .read()
+                    .await
+                    .handle_infrastructure_message(
+                        sender,
+                        msg_id,
+                        msg_authority,
+                        dst_location,
+                        msg,
+                        payload,
+                        known_keys,
+                    )
+                    .await
+            }
+            Command::PrepareNodeMsgToSend { msg, dst } => {
+                self.core.read().await.prepare_node_msg(msg, dst)
+            }
+            Command::HandleMessage { sender, wire_msg } => {
+                self.core
+                    .read()
+                    .await
+                    .handle_message(sender, wire_msg)
                     .await
             }
             Command::HandleTimeout(token) => self.core.write().await.handle_timeout(token),
@@ -167,10 +245,6 @@ impl Dispatcher {
                     .await
             }
             Command::ParseAndSendWireMsg(wire_msg) => self.send_wire_message(wire_msg).await,
-            Command::RelayMessage(wire_msg) => {
-                let cmd = self.core.write().await.relay_message(wire_msg).await?;
-                Ok(vec![cmd])
-            }
             Command::ScheduleTimeout { duration, token } => Ok(self
                 .handle_schedule_timeout(duration, token)
                 .await
@@ -208,7 +282,7 @@ impl Dispatcher {
                             name: core.node().name(),
                             section_pk,
                         },
-                        NodeMsg::StartConnectivityTest(name),
+                        SystemMsg::StartConnectivityTest(name),
                         section_pk,
                     )?
                 };
@@ -262,27 +336,10 @@ impl Dispatcher {
             MsgKind::NodeAuthMsg(_)
             | MsgKind::NodeBlsShareAuthMsg(_)
             | MsgKind::SectionAuthMsg(_) => {
-                let status = self
-                    .core
-                    .read()
-                    .await
-                    .comm
-                    .send(recipients, delivery_group_size, wire_msg)
-                    .await?;
-
-                match status {
-                    SendStatus::MinDeliveryGroupSizeReached(failed_recipients)
-                    | SendStatus::MinDeliveryGroupSizeFailed(failed_recipients) => {
-                        Ok(failed_recipients
-                            .into_iter()
-                            .map(Command::HandlePeerLost)
-                            .collect())
-                    }
-                    _ => Ok(vec![]),
-                }
-                .map_err(|e: Error| e)?
+                self.deliver_messages(recipients, delivery_group_size, wire_msg)
+                    .await?
             }
-            MsgKind::ServiceMsg(_) | MsgKind::SectionInfoMsg => {
+            MsgKind::ServiceMsg(_) => {
                 let _ = self
                     .core
                     .read()
@@ -298,45 +355,70 @@ impl Dispatcher {
         Ok(cmds)
     }
 
-    /// Send a message.
-    /// Messages sent here, either section to section or node to node.
-    pub(super) async fn send_wire_message(&self, mut wire_msg: WireMsg) -> Result<Vec<Command>> {
-        if let DstLocation::EndUser(EndUser { socket_id, xorname }) = wire_msg.dst_location() {
-            if self.core.read().await.section().prefix().matches(xorname) {
-                let addr = self.core.read().await.get_socket_addr(*socket_id).copied();
+    async fn deliver_messages(
+        &self,
+        recipients: &[(XorName, SocketAddr)],
+        delivery_group_size: usize,
+        wire_msg: WireMsg,
+    ) -> Result<Vec<Command>> {
+        let status = self
+            .core
+            .read()
+            .await
+            .comm
+            .send(recipients, delivery_group_size, wire_msg)
+            .await?;
 
-                if let Some(socket_addr) = addr {
-                    // Send a message to a client peer.
-                    // Messages sent to a client are not signed
-                    // or validated as part of the routing library.
-                    debug!("Sending client msg to {:?}: {:?}", socket_addr, wire_msg);
-
-                    let recipients = vec![(*xorname, socket_addr)];
-                    wire_msg.set_dst_section_pk(
-                        *self.core.read().await.section_chain().clone().last_key(),
-                    );
-
-                    let command = Command::SendMessage {
-                        recipients,
-                        wire_msg,
-                    };
-                    return Ok(vec![command]);
-                } else {
-                    error!(
-                        "End user msg dropped. Could not find socketaddr corresponding to socket_id {:?}: {:?}",
-                        socket_id, wire_msg
-                    );
-                    return Ok(vec![]);
-                }
-            } else {
-                debug!(
-                    "Relaying end user message (Command::RelayMessage): {:?}",
-                    wire_msg
-                );
-            }
+        match status {
+            SendStatus::MinDeliveryGroupSizeReached(failed_recipients)
+            | SendStatus::MinDeliveryGroupSizeFailed(failed_recipients) => Ok(failed_recipients
+                .into_iter()
+                .map(Command::HandlePeerLost)
+                .collect()),
+            _ => Ok(vec![]),
         }
+        .map_err(|e: Error| e)
+    }
 
-        Ok(vec![Command::RelayMessage(wire_msg)])
+    /// Send a message, either section to section, node to node, or to an end user.
+    pub(super) async fn send_wire_message(&self, mut wire_msg: WireMsg) -> Result<Vec<Command>> {
+        if let DstLocation::EndUser(EndUser(name)) = wire_msg.dst_location() {
+            let addr = self
+                .core
+                .read()
+                .await
+                .comm
+                .get_socket_addr_by_id(name)
+                .await;
+
+            if let Some(socket_addr) = addr {
+                // Send a message to a client peer.
+                // Messages sent to a client are not signed
+                // or validated as part of the routing library.
+                debug!("Sending client msg to {:?}: {:?}", socket_addr, wire_msg);
+
+                let recipients = vec![(*name, socket_addr)];
+                wire_msg
+                    .set_dst_section_pk(*self.core.read().await.section_chain().clone().last_key());
+
+                let command = Command::SendMessage {
+                    recipients,
+                    wire_msg,
+                };
+
+                Ok(vec![command])
+            } else {
+                error!(
+                        "End user msg dropped. Could not find socketaddr corresponding to xorname {:?}: {:?}",
+                        name, wire_msg
+                    );
+                Ok(vec![])
+            }
+        } else {
+            // This message is not for an end user, then send it to peer/s over the network
+            let cmd = self.core.read().await.send_msg_to_peers(wire_msg)?;
+            Ok(vec![cmd])
+        }
     }
 
     async fn handle_schedule_timeout(&self, duration: Duration, token: u64) -> Option<Command> {
