@@ -1205,7 +1205,7 @@ impl Url {
     }
 
     fn xor_name_from_nrs_string(name: &str) -> XorName {
-        XorName::from_content(&[name.as_bytes()])
+        XorName::from_content(name.as_bytes())
     }
 }
 
